PP2TlvDump

Trait PP2TlvDump 

pub trait PP2TlvDump: Debug + Display {
    // Required methods
    fn get_type(&self) -> u8;
    fn dump(&self, cur: &mut Cursor<Vec<u8>>) -> HaProxRes<()>;
}

Required Methods

fn get_type(&self) -> u8

Returns the type number of the TLV.

fn dump(&self, cur: &mut Cursor<Vec<u8>>) -> HaProxRes<()>

Writes the content of the instance to the TLV’s payload. It must NOT write the TLV header, it is written before and after.

Arguments
  • cur - a Cursor which points to the beginning of the payload. The packet size should not exceed the MTU of your network.
Returns

A Result should be returned without any inner data.

Implementors