Module protocol_raw

Module protocol_raw 

Structs

Ipv4Addr
Ipv6Addr
PP2Tlv
PP2TlvSsl
ProxyHdrV2
UnixAddr

Constants

HEADER_MAGIC_V1
Characters match the US-ASCII representation of “PROXY”
HEADER_MAGIC_V2
Binary header format starts with a constant 12 bytes.
HEADER_MAGIC_V1_STR
HEADER_MAGINC_LEN
Length if the HEADER_MAGIC_V2
HEADER_UNIX_ADDR_LEN
HEADER_V1_EOM
HEADER_V1_INET_TCP4
\x54 \x43 \x50 \x34
HEADER_V1_INET_TCP6
\x54 \x43 \x50 \x36
HEADER_V1_INET_UNKNWON
HEADER_V1_MAX_LEN
108-byte buffer is always enough to store all the line and a trailing zero for string processing.
HEADER_V1_WSPACE
MSG_HEADER_LOCAL_V2
Binary header format starts with a constant 12 bytes.

Unions

ProxyAddr