Module protocol_v2

Module protocol_v2 

Modules

autogen
protocol
protocol_composer
protocol_parser

Traits

PP2TlvDump
PP2TlvRestore
A trait which provides functionality for protocol_parser. A user’s program can implement this on the own set of TLV in order to parse the received data and return the result.
PP2TlvUniqId
Should be implemented by the structure which contains UniqID in order to be passed as argument to TLV.
ProxyV2OpCode
A V2 OP code.