Module protocol

Module protocol 

Structs

PP2TlvClient
A client flags.
PP2TlvsTypeSsl
A specific for PP2Tlv SSL.

Enums

HdrV2Command
An OP codes definotions.
PP2Tlvs
Can be used for testing.
ProtocolVersion
Defines the protocol versions.
ProxyTransportFam
A transport family.
ProxyV2Addr
An address re-representation. Can be initialized using TryFrom implementations.
ProxyV2AddrType
A quote from protocol descr:

Constants

MAX_UNIQ_ID_LEN_BYTES
Max length of the TLV’s payload uniq ID.
PP2_TYPE_MAX_CUSTOM
values is reserved for application-specific data and will be never used by the PROXY Protocol (max type)
PP2_TYPE_MAX_EXPERIMENT
reserved for temporary experimental use by application developers and protocol designers (max range)
PP2_TYPE_MAX_FUTURE
reserved for future use (max range)
PP2_TYPE_MIN_CUSTOM
values is reserved for application-specific data and will be never used by the PROXY Protocol (minimal type)
PP2_TYPE_MIN_EXPERIMENT
reserved for temporary experimental use by application developers and protocol designers (min range)
PP2_TYPE_MIN_FUTURE
reserved for future use (min range)
TLV_HEADER_LEN
Header length of TLV