ProxyTransportFam

Enum ProxyTransportFam 

#[repr(u8)]
pub enum ProxyTransportFam { UNSPEC = 0, STREAM = 1, DGRAM = 2, }
A transport family.

Other values are unspecified and must not be emitted in version 2 of this protocol and must be rejected as invalid by receivers.`

Variants



UNSPEC = 0

the connection is forwarded for an unknown, unspecified or unsupported protocol. The sender should use this family when sending LOCAL commands or when dealing with unsupported protocol families. The receiver is free to accept the connection anyway and use the real endpoint addresses or to reject it. The receiver should ignore address information.



STREAM = 1

the forwarded connection uses a SOCK_STREAM protocol (eg: TCP or UNIX_STREAM). When used with AF_INET/AF_INET6 (TCP), the addresses are followed by the source and destination ports represented on 2 bytes each in network byte order.



DGRAM = 2

the forwarded connection uses a SOCK_DGRAM protocol (eg: UDP or UNIX_DGRAM). When used with AF_INET/AF_INET6 (UDP), the addresses are followed by the source and destination ports represented on 2 bytes each in network byte order.