ProxyV2Addr

Enum ProxyV2Addr 

pub enum ProxyV2Addr {
    Ip {
        src: SocketAddr,
        dst: SocketAddr,
    },
    Unix {
        src: SocketAddr,
        dst: SocketAddr,
    },
}
An address re-representation. Can be initialized using TryFrom implementations.

TryFrom(“ip:port”, “ip:port”) TryFrom(IpAddr, u16, IpAddr, u16) TryFrom(net::SocketAddr, net::SocketAddr) TryFrom(SocketAddr, SocketAddr)

The type will be determined automatically.

Variants



Ip

AF_INET, AF_INET6

Fields



Unix

AF_UNIX

Fields

Implementations

Source

impl ProxyV2Addr

pub fn get_len(&self) -> u16

Returns the length in bytes for the current address. It returns full size, but not the actual ocupied length (for unix addresses).

pub fn as_addr_family(&self) -> ProxyV2AddrType

Returns the address type.

pub fn read( addr_fam: ProxyV2AddrType, cur: &mut Cursor<&[u8]>, ) -> HaProxRes<Option<Self>>

Reads the address section of the HaProxy. The address family should be obtained from the same packet before. The cur must point to the beginning of the address block.

Returns

The Result is returned. The Option::None will be returned only if the addr_fam is ProxyV2AddrType::AfUnspec.

pub fn write(&self, cur: &mut Cursor<Vec<u8>>) -> HaProxRes<()>

Writes the content of the current instance to packet in format of the HaProxy address. The cur Cursor should point to the beginning of the address block.