ProxyV2TlvSource

Enum ProxyV2TlvSource 

pub enum ProxyV2TlvSource<'zc, PAR: PP2TlvRestore<'zc>, EXT: PP2TlvRestore<'zc>> {
    Internal(PAR::TlvTblRes),
    External(EXT::TlvTblRes),
    Error(HaProxErr),
}
An enum which is returned by the TLV iterator. It may contain either parsed TLV or error description which occured during parsing. Normally, in case of error, the parsing should be stopped and connection dropped.

Variants



Internal(PAR::TlvTblRes)

A base implementation of the protocl.



External(EXT::TlvTblRes)

A user’s extension to the protocol.



Error(HaProxErr)

Error during parsing.

Implementations

Source

impl<'zc, PAR: PP2TlvRestore<'zc>, EXT: PP2TlvRestore<'zc>> ProxyV2TlvSource<'zc, PAR, EXT>

pub fn take_internal(self) -> Option<PAR::TlvTblRes>

Consumes the instance returning the PP2Tlvs build-in TLV through Option. If instance os not Internal then instance will be lost.

Examples found in repository?
examples/example_custom_parser.rs (line 106)
71fn main() -> HaProxRes<()>
72{
73
74    let pkt_ssl = 
75b"\x0d\x0a\x0d\x0a\x00\x0d\x0a\x51\x55\x49\x54\x0a\x21\x11\x00\x29\
76\x7f\x00\x00\x01\x7f\x00\x00\x43\x9b\x4a\x2e\x6b\x20\x00\x0f\x01\
77\x00\x00\x00\x00\x21\x00\x07\x54\x4c\x53\x76\x31\x2e\x32\xE0\x00\
78\x08\x01\x02\x03\x04\x05\x06\x07\x08";
79
80        let dec = ProxyV2Parser::<PPV2ParserZeroCopy, ProxyV2Dummy2>::try_from_slice_custom(pkt_ssl.as_slice()).unwrap();
81
82        assert_eq!(dec.get_transport().is_ok(), true);
83        assert_eq!(dec.get_transport().unwrap(), ProxyTransportFam::STREAM);
84
85        assert_eq!(dec.get_proto_version(), ProtocolVersion::V2);
86        assert_eq!(dec.get_proto_command(), HdrV2Command::PROXY);
87
88        assert_eq!(dec.get_address_family().is_ok(), true);
89        assert_eq!(dec.get_address_family().unwrap(), ProxyV2AddrType::AfInet);
90        
91        let addr = dec.get_address().unwrap();
92
93        assert_eq!(addr.is_some(), true);
94
95        let addr = addr.unwrap();
96        let maddr = ProxyV2Addr::try_from(("127.0.0.1:39754", "127.0.0.67:11883")).unwrap();
97
98        assert_eq!(addr, maddr);
99
100        let tlv_iter = dec.get_tlvs_iter();
101
102        assert_eq!(tlv_iter.is_some(), true);
103
104        let mut tlv_iter = tlv_iter.unwrap();
105
106        let type_ssl = tlv_iter.next().unwrap().take_internal().unwrap();
107
108        assert_eq!(type_ssl.get_type(), PP2Tlvs::TYPE_SSL);
109        let PP2Tlvs::TypeSsl { client, verify } = type_ssl else {panic!("wrong")};
110
111        assert_eq!(client, PP2TlvClient::PP2_CLIENT_SSL);
112        assert_eq!(verify, 0);
113
114        // --
115        let type_ssl_version = tlv_iter.next().unwrap().take_internal().unwrap();
116
117        assert_eq!(type_ssl_version.get_type(), PP2Tlvs::TYPE_SUBTYPE_SSL_VERSION);
118
119        let PP2Tlvs::TypeSubtypeSslVersion(ssl_version) = type_ssl_version else { panic!("wrong") };
120
121        assert_eq!(ssl_version, "TLSv1.2");
122
123        // ---
124        let ext_type_e0 = tlv_iter.next().unwrap().take_external().unwrap();
125
126        assert_eq!(ext_type_e0.get_type(), 0xE0);
127
128        let ProxyV2Dummy2::SomeTlvName(arg0, arg1) = ext_type_e0 else {panic!("wrong")};
129
130        assert_eq!(arg0, 0x01020304);
131        assert_eq!(arg1, 0x05060708);
132
133
134    return Ok(());
135}
pub fn take_external(self) -> Option<EXT::TlvTblRes>

Consumes the instance returning the PP2Tlvs build-in TLV through Option. If instance os not External then instance will be lost.

Examples found in repository?
examples/example_custom_parser.rs (line 124)
71fn main() -> HaProxRes<()>
72{
73
74    let pkt_ssl = 
75b"\x0d\x0a\x0d\x0a\x00\x0d\x0a\x51\x55\x49\x54\x0a\x21\x11\x00\x29\
76\x7f\x00\x00\x01\x7f\x00\x00\x43\x9b\x4a\x2e\x6b\x20\x00\x0f\x01\
77\x00\x00\x00\x00\x21\x00\x07\x54\x4c\x53\x76\x31\x2e\x32\xE0\x00\
78\x08\x01\x02\x03\x04\x05\x06\x07\x08";
79
80        let dec = ProxyV2Parser::<PPV2ParserZeroCopy, ProxyV2Dummy2>::try_from_slice_custom(pkt_ssl.as_slice()).unwrap();
81
82        assert_eq!(dec.get_transport().is_ok(), true);
83        assert_eq!(dec.get_transport().unwrap(), ProxyTransportFam::STREAM);
84
85        assert_eq!(dec.get_proto_version(), ProtocolVersion::V2);
86        assert_eq!(dec.get_proto_command(), HdrV2Command::PROXY);
87
88        assert_eq!(dec.get_address_family().is_ok(), true);
89        assert_eq!(dec.get_address_family().unwrap(), ProxyV2AddrType::AfInet);
90        
91        let addr = dec.get_address().unwrap();
92
93        assert_eq!(addr.is_some(), true);
94
95        let addr = addr.unwrap();
96        let maddr = ProxyV2Addr::try_from(("127.0.0.1:39754", "127.0.0.67:11883")).unwrap();
97
98        assert_eq!(addr, maddr);
99
100        let tlv_iter = dec.get_tlvs_iter();
101
102        assert_eq!(tlv_iter.is_some(), true);
103
104        let mut tlv_iter = tlv_iter.unwrap();
105
106        let type_ssl = tlv_iter.next().unwrap().take_internal().unwrap();
107
108        assert_eq!(type_ssl.get_type(), PP2Tlvs::TYPE_SSL);
109        let PP2Tlvs::TypeSsl { client, verify } = type_ssl else {panic!("wrong")};
110
111        assert_eq!(client, PP2TlvClient::PP2_CLIENT_SSL);
112        assert_eq!(verify, 0);
113
114        // --
115        let type_ssl_version = tlv_iter.next().unwrap().take_internal().unwrap();
116
117        assert_eq!(type_ssl_version.get_type(), PP2Tlvs::TYPE_SUBTYPE_SSL_VERSION);
118
119        let PP2Tlvs::TypeSubtypeSslVersion(ssl_version) = type_ssl_version else { panic!("wrong") };
120
121        assert_eq!(ssl_version, "TLSv1.2");
122
123        // ---
124        let ext_type_e0 = tlv_iter.next().unwrap().take_external().unwrap();
125
126        assert_eq!(ext_type_e0.get_type(), 0xE0);
127
128        let ProxyV2Dummy2::SomeTlvName(arg0, arg1) = ext_type_e0 else {panic!("wrong")};
129
130        assert_eq!(arg0, 0x01020304);
131        assert_eq!(arg1, 0x05060708);
132
133
134    return Ok(());
135}
pub fn contains_subtype(&self) -> bool

Checks if current instance constains the subtype. For Error false is always returned.