PPV2ParserZeroCopy

Struct PPV2ParserZeroCopy 

pub struct PPV2ParserZeroCopy<'zc>(/* private fields */);
Used with ProxyV2Parser its PAR generic.

A parser which borrows the data from external buffer without copying it. The lifetime is a lifetime of the parser instance.