Modules
Traits
- PP2Tlv
Dump - PP2Tlv
Restore - A trait which provides functionality for
protocol_parser. A user’s program can implement this on the own set of TLV in order to parse the received data and return the result. - PP2Tlv
Uniq Id - Should be implemented by the structure which contains UniqID in order to be passed as argument to TLV.
- Proxy
V2Op Code - A V2 OP code.