Structs
- PP2Tlv
Client - A client flags.
- PP2Tlvs
Type Ssl - A specific for PP2Tlv SSL.
Enums
- HdrV2
Command - An OP codes definotions.
- PP2Tlvs
- Can be used for testing.
- Protocol
Version - Defines the protocol versions.
- Proxy
Transport Fam - A transport family.
- Proxy
V2Addr - An address re-representation. Can be initialized using
TryFromimplementations. - Proxy
V2Addr Type - A quote from protocol descr:
Constants
- MAX_
UNIQ_ ID_ LEN_ BYTES - Max length of the TLV’s payload uniq ID.
- PP2_
TYPE_ MAX_ CUSTOM - values is reserved for application-specific data and will be never used by the PROXY Protocol (max type)
- PP2_
TYPE_ MAX_ EXPERIMENT - reserved for temporary experimental use by application developers and protocol designers (max range)
- PP2_
TYPE_ MAX_ FUTURE - reserved for future use (max range)
- PP2_
TYPE_ MIN_ CUSTOM - values is reserved for application-specific data and will be never used by the PROXY Protocol (minimal type)
- PP2_
TYPE_ MIN_ EXPERIMENT - reserved for temporary experimental use by application developers and protocol designers (min range)
- PP2_
TYPE_ MIN_ FUTURE - reserved for future use (min range)
- TLV_
HEADER_ LEN - Header length of TLV